# How to Contribute

1. Fork the repo
1. Make your changes
1. Follow local style consistency, then PEP8
1. Run pyflakes/frosted on your diffs
1. Add unit tests, make sure they pass =)
1. Send me a pull request w/ explanation of design decisions
